@@ -48,6 +48,8 @@ struct _AtspiDeviceLegacyPrivate
   guint virtual_mods_enabled;
   gboolean keyboard_grabbed;
   unsigned int numlock_physical_mask;
+  gint force_consume_mode;
+  struct timeval lock_toggle_time;
 };
 
 GObjectClass *device_legacy_parent_class;
@@ -90,6 +92,7 @@ key_cb (AtspiDeviceEvent *event, void *user_data)
   gboolean ret = priv->keyboard_grabbed;
   guint modifiers;
 
+  g_object_ref (legacy_device);
   set_virtual_modifier (legacy_device, event->hw_code,
                         event->type == (AtspiEventType) ATSPI_KEY_PRESS);
 
@@ -97,6 +100,38 @@ key_cb (AtspiDeviceEvent *event, void *user_data)
   if (modifiers & (1 << ATSPI_MODIFIER_NUMLOCK))
     modifiers &= ~priv->numlock_physical_mask;
 
+  if (find_virtual_mapping (legacy_device, event->hw_code))
+    {
+      if (event->type == (AtspiEventType) ATSPI_KEY_PRESS)
+        {
+          if (priv->force_consume_mode == 0 || priv->force_consume_mode == 4)
+            priv->force_consume_mode = 1;
+          else if (priv->force_consume_mode == 2)
+            {
+              struct timeval tv_now, tv_diff;
+              gettimeofday (&tv_now, NULL);
+              timersub (&tv_now, &priv->lock_toggle_time, &tv_diff);
+              priv->force_consume_mode = (tv_diff.tv_sec == 0 && tv_diff.tv_usec < 500000) ? 3 : 1;
+            }
+        }
+      else
+        {
+          if (priv->force_consume_mode == 1)
+            {
+              gettimeofday (&priv->lock_toggle_time, NULL);
+              priv->force_consume_mode = 2;
+            }
+          else if (priv->force_consume_mode == 3)
+            priv->force_consume_mode = 4;
+        }
+      if (priv->force_consume_mode < 3)
+        ret = TRUE;
+    }
+  else
+    {
+      priv->force_consume_mode = 0;
+    }
+
   ret |= atspi_device_notify_key (ATSPI_DEVICE (legacy_device),
                                   event->type == (AtspiEventType) ATSPI_KEY_PRESS,
                                   event->hw_code, event->id,
@@ -104,6 +139,7 @@ key_cb (AtspiDeviceEvent *event, void *user_data)
                                   event->event_string);
 
   g_boxed_free (ATSPI_TYPE_DEVICE_EVENT, event);
+  g_object_unref (legacy_device);
   return ret;
 }
 
