@@ -93,8 +93,6 @@ dbus_bool_t _atspi_dbus_call (gpointer obj, const char *interface, const char *m
 
 DBusMessage *_atspi_dbus_call_partial (gpointer obj, const char *interface, const char *method, GError **error, const char *type, ...);
 
-DBusMessage *_atspi_dbus_call_partial_va (gpointer obj, const char *interface, const char *method, GError **error, const char *type, va_list args);
-
 dbus_bool_t _atspi_dbus_get_property (gpointer obj, const char *interface, const char *name, GError **error, const char *type, void *data);
 
 DBusMessage *_atspi_dbus_send_with_reply_and_block (DBusMessage *message, GError **error);
@@ -162,8 +160,6 @@ GHashTable *_atspi_dbus_update_cache_from_dict (AtspiAccessible *accessible, DBu
 gboolean _atspi_prepare_screen_reader_interface ();
 
 gchar *_atspi_strdup_and_adjust_for_dbus (const char *s);
-
-gboolean _atspi_key_is_on_keypad (gint keycode);
 G_END_DECLS
 
 #endif /* _ATSPI_MISC_PRIVATE_H_ */
