@@ -244,74 +244,6 @@ dbind_method_call_reentrant (DBusConnection *cnx,
   return success;
 }
 
-/*---------------------------------------------------------------------------*/
-
-/* TODO: opt_error is unused; should be removed */
-dbus_bool_t
-dbind_emit_signal_va (DBusConnection *cnx,
-                      const char *path,
-                      const char *interface,
-                      const char *signal,
-                      DBusError *opt_error,
-                      const char *arg_types,
-                      va_list args)
-{
-  dbus_bool_t success = FALSE;
-  DBusMessage *msg = NULL;
-  DBusMessageIter iter;
-  const char *p;
-
-  msg = dbus_message_new_signal (path, interface, signal);
-  if (!msg)
-    goto out;
-
-  p = arg_types;
-  dbus_message_iter_init_append (msg, &iter);
-  dbind_any_marshal_va (&iter, &p, args);
-
-  if (!dbus_connection_send (cnx, msg, NULL))
-    goto out;
-
-  success = TRUE;
-out:
-
-  if (msg)
-    dbus_message_unref (msg);
-
-  return success;
-}
-
-/**
- * dbind_emit_signal:
- *
- * @cnx:       A D-Bus Connection used to make the method call.
- * @path:      The D-Bus object path that this signal is emitted from.
- * @interface: The D-Bus interface used to scope the method name.
- * @signal:    Name of signal to emit.
- * @opt_error: D-Bus error.
- * @arg_types: Variable length arguments interleaving D-Bus argument types
- *             and pointers to argument data.
- *
- * Emits a D-Bus signal  using the supplied signal name and argument data.
- **/
-dbus_bool_t
-dbind_emit_signal (DBusConnection *cnx,
-                   const char *path,
-                   const char *interface,
-                   const char *signal,
-                   DBusError *opt_error,
-                   const char *arg_types,
-                   ...)
-{
-  dbus_bool_t success = FALSE;
-  va_list args;
-
-  va_start (args, arg_types);
-  success = dbind_emit_signal_va (cnx, path, interface, signal, opt_error, arg_types, args);
-  va_end (args);
-
-  return success;
-}
 void
 dbind_set_timeout (int timeout)
 {
